unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ComCtrls, ExtCtrls,
  ZylCustomGPSReceiver, ZylFileGPSReceiver, Buttons;

type
  TfrmMain = class(TForm)
    btnStart: TButton;
    btnStop: TButton;
    memRaw: TMemo;
    GroupBox1: TGroupBox;
    efLatDeg: TEdit;
    Label1: TLabel;
    efLatMin: TEdit;
    Label2: TLabel;
    efLatSec: TEdit;
    Label3: TLabel;
    efLatDir: TEdit;
    Label4: TLabel;
    GroupBox2: TGroupBox;
    Label5: TLabel;
    Label6: TLabel;
    Label7: TLabel;
    Label8: TLabel;
    efLongDeg: TEdit;
    efLongMin: TEdit;
    efLongSec: TEdit;
    efLongDir: TEdit;
    GroupBox3: TGroupBox;
    Label9: TLabel;
    Label10: TLabel;
    Label11: TLabel;
    Label12: TLabel;
    efAlt: TEdit;
    efSpeed: TEdit;
    efCourse: TEdit;
    efSatCount: TEdit;
    Label13: TLabel;
    Label15: TLabel;
    Label16: TLabel;
    lblUTCTime: TLabel;
    lblLocalTime: TLabel;
    PaintBox: TPaintBox;
    ZylGPSReceiver: TZylFileGPSReceiver;
    efFile: TEdit;
    Label14: TLabel;
    btnBrowseTitle: TBitBtn;
    OpenDialog: TOpenDialog;
    procedure btnStartClick(Sender: TObject);
    procedure btnStopClick(Sender: TObject);
    procedure ZylGPSReceiverSpeedChange(Sender: TObject; Value: Extended);
    procedure ZylGPSReceiverHeadingChange(Sender: TObject; Value: Extended);
    procedure ZylGPSReceiverConnect(Sender: TObject; FileName: String);
    procedure ZylGPSReceiverDisconnect(Sender: TObject; FileName: String);
    procedure ZylGPSReceiverAltitudeChange(Sender: TObject; Value: Extended);
    procedure ZylGPSReceiverLatitudeChange(Sender: TObject; Degree,
      Minute: Integer; Second: Extended; Direction: TCardinalPoint);
    procedure ZylGPSReceiverLongitudeChange(Sender: TObject; Degree,
      Minute: Integer; Second: Extended; Direction: TCardinalPoint);
    procedure ZylGPSReceiver2DPositionChange(Sender: TObject; Latitude,
      Longitude: Extended);
    procedure ZylGPSReceiver3DPositionChange(Sender: TObject; Latitude,
      Longitude, Altitude: Extended);
    procedure ZylGPSReceiverSatelliteReceive(Sender: TObject;
      Satellite: TSatellite);
    procedure PaintBoxPaint(Sender: TObject);
    procedure ZylGPSReceiverSatellitesReceive(Sender: TObject);
    procedure btnBrowseTitleClick(Sender: TObject);
    {$ifdef UNICODE}
    procedure ZylGPSReceiverReceive(Sender: TObject; Buffer: AnsiString);
    {$else}
    procedure ZylGPSReceiverReceive(Sender: TObject; Buffer: String);
    {$endif}
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  frmMain: TfrmMain;

implementation

{$R *.dfm}

procedure TfrmMain.btnStartClick(Sender: TObject);
begin
  ZylGPSReceiver.FileName := efFile.Text;
  ZylGPSReceiver.Open;
end;

procedure TfrmMain.btnStopClick(Sender: TObject);
begin
  ZylGPSReceiver.Close;
end;

procedure TfrmMain.ZylGPSReceiverSpeedChange(Sender: TObject; Value: Extended);
begin
  memRaw.Lines.Add('Speed Changed:' + FloatToStr(Value) + ' KM/H');
end;

procedure TfrmMain.ZylGPSReceiverHeadingChange(Sender: TObject;
  Value: Extended);
begin
  memRaw.Lines.Add('Heading Changed:' + FloatToStr(Value) + ' Degrees');
end;

procedure TfrmMain.ZylGPSReceiverConnect(Sender: TObject; FileName: String);
begin
  memRaw.Lines.Add('Connected to: ' + ZylGPSReceiver.FileName);
end;

procedure TfrmMain.ZylGPSReceiverDisconnect(Sender: TObject;
  FileName: String);
begin
  memRaw.Lines.Add('Disconnected from: ' + ZylGPSReceiver.FileName);
end;

procedure TfrmMain.ZylGPSReceiverAltitudeChange(Sender: TObject;
  Value: Extended);
begin
  memRaw.Lines.Add('Altitude Changed:' + FloatToStr(Value) + ' M');
end;

procedure TfrmMain.ZylGPSReceiverLatitudeChange(Sender: TObject; Degree,
  Minute: Integer; Second: Extended; Direction: TCardinalPoint);
begin
  memRaw.Lines.Add('Latitude Changed: ' + FloatToStr(ZylGPSReceiver.DMSToDecimalDegrees(Degree, Minute, Second, Direction)));
end;

procedure TfrmMain.ZylGPSReceiverLongitudeChange(Sender: TObject; Degree,
  Minute: Integer; Second: Extended; Direction: TCardinalPoint);
begin
  memRaw.Lines.Add('Longitude Changed: ' + FloatToStr(ZylGPSReceiver.DMSToDecimalDegrees(Degree, Minute, Second, Direction)));
end;

procedure TfrmMain.ZylGPSReceiver2DPositionChange(Sender: TObject;
  Latitude, Longitude: Extended);
begin
  memRaw.Lines.Add('2D Position Changed. Distance to New York City = ' + FloatToStr(ZylGPSReceiver.Distance_Km(Latitude, Longitude, 40.77, 73.98)) + ' KM');
end;

procedure TfrmMain.ZylGPSReceiver3DPositionChange(Sender: TObject;
  Latitude, Longitude, Altitude: Extended);
begin
  memRaw.Lines.Add('3D Position Changed.');
end;

procedure TfrmMain.ZylGPSReceiverSatelliteReceive(Sender: TObject;
  Satellite: TSatellite);
var
  str: String;
begin
  str := 'Satellite Received' + ' Code=' + IntToStr(Satellite.PseudoRandomCode);
  str := str + ' Elevation=' + IntToStr(Satellite.Elevation);
  str := str + ' Azimuth=' + IntToStr(Satellite.Azimuth);
  str := str + ' Signal=' + IntToStr(Satellite.SignalToNoiseRatio);
  memRaw.Lines.Add(str);
end;

procedure TfrmMain.PaintBoxPaint(Sender: TObject);
begin
  ZylGPSReceiver.DrawSatellites(PaintBox.Canvas, PaintBox.Width div 2,
    clBlack, clWhite);
end;

procedure TfrmMain.ZylGPSReceiverSatellitesReceive(Sender: TObject);
begin
  PaintBox.Repaint;
end;

procedure TfrmMain.btnBrowseTitleClick(Sender: TObject);
begin
  if OpenDialog.Execute then
  begin
    if Length(OpenDialog.FileName) > 3 then
    begin
      efFile.Text := OpenDialog.FileName;
    end;
  end;
end;

{$ifdef Unicode}
procedure TfrmMain.ZylGPSReceiverReceive(Sender: TObject; Buffer: AnsiString);
{$else}
procedure TfrmMain.ZylGPSReceiverReceive(Sender: TObject; Buffer: String);
{$endif}
begin
  efLatDeg.Text := IntToStr(ZylGPSReceiver.GetLatitudeDegree);
  efLatMin.Text := IntToStr(ZylGPSReceiver.GetLatitudeMinute);
  efLatSec.Text := FloatToStr(ZylGPSReceiver.GetLatitudeSecond);
  if ZylGPSReceiver.GetLatitudeDirection = cpNorth then
    efLatDir.Text := 'North'
  else
    efLatDir.Text := 'South';

  efLongDeg.Text := IntToStr(ZylGPSReceiver.GetLongitudeDegree);
  efLongMin.Text := IntToStr(ZylGPSReceiver.GetLongitudeMinute);
  efLongSec.Text := FloatToStr(ZylGPSReceiver.GetLongitudeSecond);
  if ZylGPSReceiver.GetLongitudeDirection = cpEast then
    efLongDir.Text := 'East'
  else
    efLongDir.Text := 'West';

  efAlt.Text := FloatToStr(ZylGPSReceiver.GetAltitude);
  efSpeed.Text := FloatToStr(ZylGPSReceiver.GetSpeed_KMH);
  efCourse.Text := FloatToStr(ZylGPSReceiver.GetCourse);
  efSatCount.Text := IntToStr(ZylGPSReceiver.GetSatelliteCount);

  lblUTCTime.Caption := DateTimeToStr(ZylGPSReceiver.GetUTCDateTime);
  lblLocalTime.Caption := DateTimeToStr(ZylGPSReceiver.GetLocalDateTime);

  try
    memRaw.Lines.Add(Buffer);
    memRaw.Lines.Add('Fix = ' + IntToStr(ZylGPSReceiver.IsFix));
    //AssignFile(f, 'c:\gpsout.txt');
    //Append(f);
    //Write(f, ZylGPSReceiver.GetRawData);
    //CloseFile(f);
    memRaw.Lines.Add('---------------------------------------------------------')
  except
    memRaw.Lines.Clear;
  end;
end;

procedure TfrmMain.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  if ZylGPSReceiver.IsConnected then
    ZylGPSReceiver.Close();
end;

end.
